lydia <- read.table("//ad.uni-hamburg.de/basis/mit/bm01/BAB5975/Documents/Lehre/ZRA/Anwendungen/lydiapink/lydiapink.txt", header = F)
sales <- ts(lydia[,1], start = 1, freq = 1)
advert <- ts(lydia[,2], start = 1, freq = 1)
a <- diff(advert,1)
plot(a, type = "o")
a <- a - mean(a)

par(mfrow = c(1,2))
acf(a, lag.max = 20, xlab=expression(tau), main = "ACF mit Bartlett-Grenzen", ci.type = "ma")
pacf(a, lag.max = 20, xlab=expression(tau), main = "PACF mit White-Noise-Grenzen")
#Entscheidung: AR[4]
#(Im Allgemeinen ist es gewnscht ein AR-Modell an dem stoch. Regressoren anzupassen. 
#Grund: AR-Modelle sind einfacher zu schtzen, einfacher zu interpretieren, gnstiger fr Folgeoperationen.)

##Anpassung eines AR[4]-Modells an die Reihe a
out.a <- ar(a, order.max = 4, aic = F, include.mean = F)
out.a

# ACF und PACF der Residuen
par(mfrow = c(1,2))
acf(out.a$resid[5:length(out.a$resid)], lag.max = 20, xlab=expression(tau), main = "ACF mit Bartlett-Grenzen", ci.type = "ma")
pacf(out.a$resid[5:length(out.a$resid)], lag.max = 20, xlab=expression(tau), main = "PACF mit White-Noise-Grenzen")

#berprfung der Parametersignifikanz
coef <- out.a$ar
tstat <- round(out.a$ar/diag(out.a$asy.var.coef)^.5, 4)
pwert<- round(2*(1-pnorm(abs(tstat))),4)
cbind(coef, tstat, pwert)

#Anpassung eines Subset-AR[4]-Modells an die Reihe a
fix = c( NA, NA, 0, NA)
out.a <- arima(a, order = c(4,0,0), fixed =fix, include.mean = F)
out.a

# ACF und PACF der Residuen
par(mfrow = c(1,2))
acf(out.a$resid, lag.max = 20, xlab=expression(tau), main = "ACF mit Bartlett-Grenzen", ci.type = "ma")
pacf(out.a$resid, lag.max = 20, xlab=expression(tau), main = "PACF mit White-Noise-Grenzen")

#berprfung der Parametersignifikanz
coef <- out.a$coef[c(1,2,4)]
tstat <- round(coef/diag(out.a$var.coef)^.5, 4)
pwert<- round(2*(1-pnorm(abs(tstat))),4)
cbind(coef, tstat, pwert)

#Anpassung eines Subset-AR[4]-Modells an die Reihe a
fix = c( 0, NA, 0, NA)
out.a <- arima(a, order = c(4,0,0), fixed =fix, include.mean = F)
out.a

# ACF und PACF der Residuen
par(mfrow = c(1,2))
acf(out.a$resid, lag.max = 20, xlab=expression(tau), main = "ACF mit Bartlett-Grenzen", ci.type = "ma")
pacf(out.a$resid, lag.max = 20, xlab=expression(tau), main = "PACF mit White-Noise-Grenzen")

#berprfung der Parametersignifikanz
coef <- out.a$coef[c(2,4)]
tstat <- round(coef/diag(out.a$var.coef)^.5, 4)
pwert<- round(2*(1-pnorm(abs(tstat))),4)
cbind(coef, tstat, pwert)

#Box-Pierce-Ljung Test
res <- out.a$resid
n.par <- 2 # Anzahl geschtzter Parameter
Box <- matrix(0,4,3)
m <- c(12,14,16,18)
m <- m[m>n.par]
for(i in c(1:length(m))){
bt <- Box.test(res, lag = m[i], type = "Ljung-Box")
pw <- 1-pchisq(bt$statistic, m[i]-n.par)
Box[i,]<- c(bt$parameter, bt$statistic, pw)}
colnames(Box)<- c("Lags", "Statistik", "P-Wert")
Box