lydia <- read.table("//ad.uni-hamburg.de/basis/mit/bm01/BAB5975/Documents/Lehre/ZRA/Anwendungen/lydiapink/lydiapink.txt", header = F)
sales <- ts(lydia[,1], start = 1, freq = 1)
advert <- ts(lydia[,2], start = 1, freq = 1)
plot(sales, ylim = c(0,4000))
lines(advert, col= "red")

s <- diff(sales,1)
a <- diff(advert,1)
plot(s, type = "o")
plot(a, type = "o")
a <- a - mean(a)
s <- s - mean(s)

#*******************************************************************************************
#I. Identifikation und vorlufige Schtzung der Transferfunktion 
#I.1 Anpassung eines ARMA-Modells an die Reihe a
par(mfrow = c(1,2))
acf(a, lag.max = 20, xlab=expression(tau), main = "ACF mit Bartlett-Grenzen", ci.type = "ma")
pacf(a, lag.max = 20, xlab=expression(tau), main = "PACF mit White-Noise-Grenzen")
##Entscheidung: AR[4]
#s. die Datei Modellanpassung_advert.R 
#(Im Allgemeinen ist es gewnscht ein AR-Modell an dem stoch. Regressoren anzupassen. 
#Grund: AR-Modelle sind einfacher zu schtzen, einfacher zu interpretieren, gnstiger fr Folgeoperationen.)

#Anpassung eines Subset-AR[4]-Modells an die Reihe a 
fix = c( 0, NA, 0, NA)
out.a <- arima(a, order = c(4,0,0), fixed =fix, include.mean = F)
out.a

# ACF und PACF der Residuen
par(mfrow = c(1,2))
acf(out.a$resid, lag.max = 20, xlab=expression(tau), main = "ACF mit Bartlett-Grenzen", ci.type = "ma")
pacf(out.a$resid, lag.max = 20, xlab=expression(tau), main = "PACF mit White-Noise-Grenzen")

#Box-Pierce-Ljung Test
res <- out.a$resid
n.par <- 2 # Anzahl geschtzter Parameter
Box <- matrix(0,4,3)
m <- c(12,14,16,18)
m <- m[m>n.par]
for(i in c(1:length(m))){
bt <- Box.test(res, lag = m[i], type = "Ljung-Box")
pw <- 1-pchisq(bt$statistic, m[i]-n.par)
Box[i,]<- c(bt$parameter, bt$statistic, pw)}
colnames(Box)<- c("Lags", "Statistik", "P-Wert")
Box

#I.2 Filtern der Input-Reihe (Prewhitening)
input <- out.a$resid[-c(1:4)]

#I.3 Filtern der Output-Reihe
N <- length(s)
output <- s[5:N] - out.a$coef[2]*s[3:(N-2)] - out.a$coef[4]*s[1:(N-4)]

#alternativ: 
fix <- out.a$coef
out_s <- arima(s, order= c(4,0,0), fixed = fix, include.mean = F)
##Die Residuen entsprechen der gefilterten Output-Reihe
output <- out_s$resid[-c(1:4)]

#I.d Schtzung der Transferfunktion auf der Grundlage der CCF der gefilterten Reihen
ccf(input, output, 10) ###Wir modellieren nur die Lags -1 und 0   
#Wir mchten die Wirksamkeit von Werbeausgaben beurteilen. 
#Daher modellieren wir nur die Lags -1 und 0, whrend das Lag 1 nicht weiter bercksichtigt wird.    
nu <- ccf(input, output, 10)  
nu <- nu$acf[c(10, 11)]*sd(output)/sd(input)  

#********************************************************************************
#II. Anpassung eines ARMA-Modells an die Residuenreihe
noise <- s[2:N] - a[2:N]*nu[2] - a[1:N-1]*nu[1]
# ACF und PACF der Reihe noise
par(mfrow = c(1,2))
acf(noise, lag.max = 20, xlab=expression(tau), main = "ACF mit Bartlett-Grenzen", ci.type = "ma")
pacf(noise, lag.max = 20, xlab=expression(tau), main = "PACF mit White-Noise-Grenzen")
#noise scheint die Realisation eines White-Noise-Prozesses zu sein.
#Daher keine weitere ARMA-Modellierug der noise-Reihe notwendig.
#Die Gesamtschtzung kann mit der Funktion arima(...order=c(0,0,0)...) oder einfach mit lm() durchgefhrt werden.

#********************************************************************************
#III. Gesamtschtzung des Transferfunktionsmodells
trans <- cbind(a[2:N], a[1:(N-1)])
out <- arima(s[2:N], order = c(0,0,0), xreg = trans, include.mean = F)
out

#alternativ
out_lm <- lm( s[2:N] ~ trans -1)
out_lm

#*******************************************************************************************
#Die geschtzte Modell-Gleichung:
#(1-B)sales = m_s + (0.6126 + 0.2052 B)((1-B)advert - m_a) + epsilon
#m_s = 5.15 ist der Mittelwert der Reihe (1-B)sales 
#m_a = -0.83 ist der Mittelwert der Reihe (1-B)advert